<!DOCTYPE html>
<!--suppress ALL -->
<html lang="en">
  <head>
    <base href="/">

    <meta charset="UTF-8">
    <title>Title</title>
    <script src="//code.jquery.com/jquery-3.2.1.min.js"></script>
    <link rel="shortcut icon" href="/static/favicon.ico">
    <script src="static/app.js"></script>
  </head>
  <body>

    <h1>Click the POST DIP SHIT</h1>

    <button id="fuck">POST POST</button>
    <h3>SEPARATOR</h3>
    <button id="fuck2">Error</button>
  </body>
</html>
